==> tecfy_corev2_package-1.1.53.tar.gz: lib/views/components/general/file_manager_page.dart <==
part of tecfy_corev2_client_package;

class FileManagerPage extends StatefulWidget {
  const FileManagerPage({Key? key}) : super(key: key);

  @override
  State<FileManagerPage> createState() => _FileManagerPageState();
}

class _FileManagerPageState extends State<FileManagerPage> {
  List<FileModel>? _myData;

  Future<List<FileModel>?> getFilesData(String? parentId) async {
    var response =
        await ApiService().httpGetDynamic('https://kafaratplus-api.tecfy'
            '.co/api/admin/setup/file/tree?parentId=${parentId ?? ''}&skip=0'
            '&count=0');
    // print(response.data);
    // print(response.success);
    // Map<String, dynamic> json = jsonDecode(response.body);

    return List<FileModel>.from(
        response.data.map((e) => FileModel.fromJson(e)));
  }

  Future<String?> uploadFile(
      String? folderId, Uint8List? pickedFile, String? pickedFileName) async {
    var response = await ApiService().httpPostFile(
        'https://kafaratplus-api.tecfy'
        '.co/api/general/storage/folder/file/admin',
        pickedFile!,
        pickedFileName!,
        {
          'type': 'File',
          if (folderId != null) 'parentId': folderId,
        });
    print(response.data);
    print(response.toString());
    return response.data;
  }

  Future<String?> createFolder(String? parentId, String? folderName) async {
    var response = await ApiService().httpPostEx(
        'https://kafaratplus-api'
        '.tecfy'
        '.co/api/general/storage/folder/file/admin',
        {
          'type': 'Folder',
          'path': folderName,
          if (parentId != null) 'parentId': parentId,
          'name': folderName
        });
    print(response.data);
    print(response.toString());
    return response.data;
  }

  @override
  void initState() {
    init();

    super.initState();
  }

  init() async {
    _myData = await getFilesData(null);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, 'الملفات', 'files',
        isMobile: LayoutService.isMobile(context),
        child: _myData != null
            ? SimpleFileManager(
          filesList: _myData!,
                uploadButtonText:
                    LocalConfigService.isArabic ? 'رفع ملف' : 'Upload File',
                createFolderText:
                    LocalConfigService.isArabic ? 'إنشاء ملف' : 'Create Folder',
                // allowedExtensionsToPick: [],
                onUpload: (String? parentId, pickedFile,
                    String? pickedFileName) async {
                  if (pickedFile != null) {
                    return await uploadFile(
                        parentId, pickedFile, pickedFileName);
                  } else {
                    return null;
                  }
                },
                onCreateFolderClicked: (String? parentID, folderName) async {
                  print(parentID);
                  print(folderName);
                  return await createFolder(parentID, folderName);
                },
                onBack: (String? value) async {
                  return await getFilesData(value);
                },
                onFolderClicked: (value) async {
                  return await getFilesData(value!.id);
                },
              )
            : Center(
                child: CircularProgressIndicator.adaptive(),
              ));
  }
}

==> tecfy_corev2_package-1.1.57.tar.gz: lib/views/components/general/file_manager_page.dart <==
part of tecfy_corev2_client_package;

class FileManagerPage extends StatefulWidget {
  const FileManagerPage({Key? key}) : super(key: key);

  @override
  State<FileManagerPage> createState() => _FileManagerPageState();
}

class _FileManagerPageState extends State<FileManagerPage> {
  List<FileModel>? _myData;

  Future<List<FileModel>?> getFilesData(String? parentId) async {
    var response =
        await ApiService().httpGetDynamic('https://kafaratplus-api.tecfy'
            '.co/api/admin/setup/file/tree?parentId=${parentId ?? ''}&skip=0'
            '&count=0');
    // print(response.data);
    // print(response.success);
    // Map<String, dynamic> json = jsonDecode(response.body);

    return List<FileModel>.from(
        response.data.map((e) => FileModel.fromJson(e)));
  }

  Future<String?> uploadFile(
      String? folderId, Uint8List? pickedFile, String? pickedFileName) async {
    bool isImage = true;
    if (pickedFileName != null) {
      if (pickedFileName.split('.').last == 'pdf' ||
          pickedFileName.split('.').last == 'xlsx') isImage = false;
    }
    var response = await ApiService().httpPostFile(
        'https://kafaratplus-api.tecfy'
        '.co/api/general/storage/folder/file/admin',
        pickedFile!,
        pickedFileName!,
        {
          'type': 'File',
          if (folderId != null) 'parentId': folderId,
        },
        {},
        isImage);
    return response.data;
  }

  Future<String?> createFolder(String? parentId, String? folderName) async {
    var response = await ApiService().httpPostEx(
        'https://kafaratplus-api'
        '.tecfy'
        '.co/api/general/storage/folder/file/admin',
        {
          'type': 'Folder',
          'path': folderName,
          if (parentId != null) 'parentId': parentId,
          'name': folderName
        });
    print(response.data);
    print(response.toString());
    return response.data;
  }

  @override
  void initState() {
    init();

    super.initState();
  }

  init() async {
    _myData = await getFilesData(null);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return BasePage(context, 'الملفات', 'files',
        isMobile: LayoutService.isMobile(context),
        child: _myData != null
            ? SimpleFileManager(
          filesList: _myData!,
                uploadButtonText:
                    LocalConfigService.isArabic ? 'رفع ملف' : 'Upload File',
                createFolderText:
                    LocalConfigService.isArabic ? 'إنشاء ملف' : 'Create Folder',
                // allowedExtensionsToPick: [],
                onUpload: (String? parentId, pickedFile,
                    String? pickedFileName) async {
                  print('PickedFileName : ${pickedFileName}');
                  if (pickedFile != null && pickedFileName != null) {
                    return await uploadFile(
                        parentId, pickedFile, pickedFileName);
                  } else {
                    return null;
                  }
                },
                onCreateFolderClicked: (String? parentID, folderName) async {
                  print(parentID);
                  print(folderName);
                  return await createFolder(parentID, folderName);
                },
                onBack: (String? value) async {
                  return await getFilesData(value);
                },
                onFolderClicked: (value) async {
                  return await getFilesData(value!.id);
                },
              )
            : Center(
                child: CircularProgressIndicator.adaptive(),
              ));
  }
}
